#
# spec file for package scantailor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scantailor
Version:        1.0.16
Release:        3.5
Summary:        Interactive post-processing tool for scanned pages
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://scantailor.sourceforge.net/
Source0:        https://github.com/4lex4/%{name}-advanced/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-icons.tar.bz2
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-build-with-Qt-5.15-missing-QPainterPath-includes.patch
BuildRequires:  cmake >= 3.9.0
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_test-devel >= 1.65.0
%else
BuildRequires:  boost-devel >= 1.65.0
%endif

%description
Scan Tailor is an interactive post-processing tool for scanned pages.
It performs operations such as page splitting, deskewing,
adding/removing borders and others. It takes raw scans, and outputs
pages ready to be printed or assembled into a PDF or DJVU file.

%prep
%autosetup -p1 -a 1 -n %{name}-advanced-%{version}
cp -p resources/icons/{COPYING,COPYING.icons}

%build
%cmake
%cmake_build

%install
%cmake_install

for s in 256 128 96 72 64 48 32 16 ; do
install -Dm 0644 scantailor-icons/scantailor-${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/scantailor.png
done
install -Dm 0644 resources/appicon.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/scantailor.svg
# Create desktop-file
cat > %{name}.desktop << EOF
[Desktop Entry]
Name=Scan Tailor
GenericName=Post-Processing Tool for Scanned Pages
GenericName[ru]=Обработка отсканированных страниц
Type=Application
Exec=scantailor
Icon=scantailor
Categories=Graphics;Scanning;Qt;
Comment=Interactive Post-Processing Tool for Scanned Pages
Comment[ru]=Интерактивная обработка отсканированных страниц
StartupNotify=true
Terminal=false
EOF
%suse_update_desktop_file -i %{name}

%files
%license LICENSE resources/icons/COPYING.icons
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*
%{_datadir}/icons/hicolor/*/*/ScanTailor.*
%{_datadir}/mime/packages/%{name}-project.xml
%dir %{_datadir}/%{name}-advanced
%dir %{_datadir}/%{name}-advanced/translations
%{_datadir}/%{name}-advanced/translations/%{name}_*.qm

%changelog
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Fix-build-with-Qt-5.15-missing-QPainterPath-includes.patch
- Spec cleanup
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.16
  * various bug fixes and improvements
  * added buttons to navigate between pages
* Tue Apr  3 2018 jengelh@inai.de
- Update description.
* Mon Apr  2 2018 aloisio@gmx.com
- Update to version 1.0.13
  * Bug fixes
  version 1.0.12
  * Implemented the feature of auto adjusting content area.
  * Deviation parameters added into the settings dialog. The
    deviation default settings have been calibrated.
  * Improved: The follow page button is no more activated
    automatically on switching a sorting method or on going to the
    previous/next page.
  * Auto and original alignment modes reworked.
  * Added the ability to separately control vertical and
    horizontal automatic alignment when auto or original alignment
    mode enabled.
  version 1.0.11
  * Fixed a possible crash at the output stage: STA used the
    wrong crop area for background estimation.
  * UI fixes for the dialog of default parameters.
    version 1.0.10
  * Added color adjustments settings for color segmenter.
  * Fixed: rectangular picture auto zones are incorrectly shifted.
  * Support for any type of input image.
  * Default parameters don't more require processing to convert
    units. It caused a bug on margins stage.
  * Improved: a default parameters profile can now be edited.
  * Added page count info beside page number into status bar.
  * Posterization improved:
    + Posterization can now correctly handle with pale images.
    + It's become possible due to normalizing the source image
    before posterizing.
    + Added normalize option so as to add the ability to get
    normalized output.
    + Force b&w option has been reworked.
  * Improved: Follow page button is no more activated
    automatically on switching a filter if the button was inactivated
    before. Instead of that behavior ST now saves the sliders
    positions.
  * Note: The old behavior caused some problems of loosing the
    position of the page sequence worked on if not natural sorting
    enabled.
  * Collapsible filter options.
  * Added "Higher search sensitivity" option into picture shape
    options.
  * It gives the same search result as it was in Enhanced (&
    Featured) versions.
  * Deviation feature reworked and added sorting by decreasing
    deviation.
  version 1.0.9
  * Fixed: ST used Otsu instead of Wolf and Sauvola binarization
    methods in some cases, ignoring the user settings.
  * Fixed: ST could cut off edges of content in auto mode.
  * Added "Off" picture shape mode.
  * Fixed possible crash on switching from rectangular to another
    picture shape mode on some builds.
  * Support for processing of images with light content on dark
    background.
  * Fixed a lag on opening the settings dialog.
  * Added project version compatibility check.
  * Implemented page area feature.
  * Implemented new zone interaction modes feature.
  * Implemented saving zoom and focus on switching output tabs
    feature.
  * Implemented measurement units system feature.
  * Implemented status bar panel feature.
  * Implemented default parameters feature.
  * Implemented original background feature.
  * Implemented color segmenter and posterization feature.
  version 1.0.8
  * Hotfix for version 1.0.7
  * Warning! Old project files aren't compatible with this
    version, you mustn't even try to open project files of
    version 1.0.7 or earlier with this version.
  version 1.0.7
  * Fix for high DPI (ex. 4K) displays.
  * Pages without content box will be blank at output. A content
    box deleted manually won't more be reset to the page bounds on
    reloading.
  * On placing a new filling zone over another it now overlaps
    the older one.
  * "Quadro" picture shape mode was merged with rectangular. Also
    removed the restriction of ver. Featured on deleting all the auto
    zones. Before it resulted in resetting all the auto zones back.
  * Added sensitivity option. If sensitivity equals 25%%, the
    results will be the same as they were in old "Quadro" mode, if
    100%% - as in old "Rectangular".
  * Fixed bug come from ver. Featured: filling zones were set to
    wrong positions in their view after manual / marginal dewarping
    with post deskew enabled.
  * Auto detection of the white on black option for Sauvola and
    Wolf binarization methods on the first time processing.
  * Applied some fixes from ver. Universal.
  * Other improvements and fixes.
  * Warning! Old project files aren't compatible with this
    version.
  version 1.0.6
  * Fixed bug from Enhanced: applying manual deskew settings to a
    multitude of pages didn't work for the pages with a size
    different from that of the page the setting is applied to.
  * That resulted in resetting those pages to auto mode on
    processing. Also now deskew changes have effect on thumbnails
    instantly without forcing to reload the pages.
  * Start batch processing dialog from Enhanced removed.
  * Splitting output options are moved out of the color settings.
    Splitting options have its own "Apply To" dialog and button now.
  * Fixed a bug of the official ST: ST could crash on output when
    outer margins and content rectangle are "touch" by its sides on
    margins stage.
  * Fixed: on switching to manual alignment mode from any other
    the content rectangle was always placed at the top center instead
    of the place set by the align buttons.
  * Fixed: Subtracting picture zones, placed over an auto layer
    picture zone, no more blink on zoom.
  * Fixed: Picture zone type used wasn't sometimes saved on page
    switching.
  * Added option to control highlighting (with red asterisks) the
    thumbnails of pages with high deviation. The option refreshes the
    thumbnails instantly.
  * Fixed: page layout view didn't consider splitting settings.
    Corresponding improvements are done to thumbnails.
  * Fixed: on applying a content box to other pages it could be
    set out of the page bounds.
  * Fixed: possible mixed pixels in the output image of right
    page after splitting.
  * Various fixes of thumbnails drawing.
  * Changed Scan Tailor behavior on page split stage.
    + Reworked apply cut feature. Now on applying cut to the
    pages with different dimensions than the page the cut
    applied to, Scan Tailor tries to adapt cutters instead of
    fully rejecting the cut setting and switching to auto mode
    for those pages as it was before. The later was annoying as
    pages could be similar and had the difference in a few pixels.
    + Added check to reject invalid cut settings in manual mode.
    + UI: Added cutters interaction between each other. They
    can't more intersect each other, which created a wrong page
    layout configuration before.
  * Fixed bug from Enhanced: on select content stage after saving
    and reopening the project the thumbnail could change its
    position on the page loading when sorting enabled.
  * Now outside pixels of color images are filled with the
    background dominant color not gray. The respective feature has
    been implemented.
  * Also added filling setting with the following options:
    + Background: estimate the background and fill outside pixels
    with its color.
    + White: always fill with white.
  * Tiff compression feature reworked.
  * Now there are two options in settings dialog: B&W and color
    compression.
    + The B&W one has None, LZW, Deflate and CCITT G4 options.
    + The color one has None, LZW, Deflate and JPEG options.
  * Other changes.
  * Warning! Project files of older versions of ST are not
    compatible with this version.
  version 1.0.5
  * fixed: a page wasn't refreshed in output on changing its crop
    area;
  * equalize illumination option does no more depend on white
    margins.
  version 1.0.4
  * fixed bug from Enhanced: picture_shape in mixed mode wasn't
    saved in the project file that caused reloading page on every
    restart in output mode.
  * fixed: filling color wasn't adapted on brightness change.
  * improved output processing in B&W mode when illumination
    equalization disabled.
  version 1.0.3
  * Images libraries reconfigured (the old configuration could
    cause some problems with some images).
  * Warning for a user of a 32-bit system: the count of threads
    for multi-threaded batch processing is limited to 2 threads due
    to memory constraints. And that is intended only for systems with
    2GB RAM. If you have only 1GB RAM and lower, don't use this
    feature and set the count of threads to 1. Otherwise you are
    risking to get "out of memory" error.
    version 1.0.2
  * Added option to disable post-deskew on dewarping.
    It should be applied to a cover with geometric distortions
    and without any text lines which the auto-deskew algorithm
    could  rely on. Also it can be applied to pages with those that
    have non-horizontal text lines as part of the design and so the
    auto-deskew algorithm fails on that kind of pages.
    The setting is located at Output -> Dewarping -> Change... ->
    Post deskew
  * Fixed: Post-deskew on dewarping enabled now fills the outside
    pixels with the dominant gray color in a color mode.
  * Added option to control white on black mode for the adaptive
    binarization methods.
    It should be enabled when the text or content is lighter than
    the background.
  version 1.0.1
  * bug fixes.
  version 1.0.0
  * Initial release after the fork. Merged the Qt5 branch from
    the original repository and the features from Scan Tailor
    Featured and Scan Tailor Enhanced
- Switch to Qt5-based (and currently maintained)
  scantailor-advanced fork
- Dropped, hopefully temporarily, the cli subpackage
- Spec cleanup
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Jun 17 2016 dmitry_r@opensuse.org
- Update to version 0.9.12.2 [boo#985096]
  * Bugfix release
  * Drop obsolete scantailor-boost-1.60.patch
* Wed Feb 24 2016 dmitry_r@opensuse.org
- Fix build with boost 1.60
  * scantailor-boost-1.60.patch
* Sat Jan 24 2015 dmitry_r@opensuse.org
- Move command line interface to separate package
* Mon Dec 29 2014 dmitry_r@opensuse.org
- Use %%cmake macros
* Sun Mar  3 2013 asterios.dramis@gmail.com
- Update to 0.9.11.1:
  * Fixed a bug affecting binarization quality in Mixed output mode.
  * Fixed borders being filled with cyan instead of white.
  * Avoid creating unwanted directories for projects requiring relinking.
  * Cosmetic improvements in Relinking dialog.
  * New translation: Brazilian Portuguese.
* Wed Jan 18 2012 lazy.kent@opensuse.org
- Update to 0.9.11.
  * Ability to fix DPI of source images in an existing project.
  * Project portability through resource relinking.
  * It's now possible to save your project in an out-of-memory
    situation.
  * New translations: Spanish, Ukrainean.
- Corrected icons size.
* Mon Aug  1 2011 lazy.kent@opensuse.org
- Update to 0.9.10.
  + Page dewarping functionality.
  + Command-line version.
  + Ability to apply content box to to multiple pages.
  + Ability to apply margins to odd and even pages separately.
  + New translations: Italian, Czech, Polish, Slovak, Traditional
    Chinese
  + Bug fixes, including a couple of crashes.
- Dropped tabbed_widget patch (don't build against Qt 4.4 anymore).
- Build requires boost-devel >= 1.42 and libqt4-devel >= 4.5.
- Install icons of different sizes.
- Added icon_theme_cache_post/un macro.
- Corrected License tag.
- Use full URL for source.
* Sun Oct 24 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.2.
  + Fixed page sorting issues on Linux.
  + Fixed improper calculation of cut-off page outline.
  + Fixed pages re-appearing in a project after being removed
    half-by-half.
  + German and French translations were added.
  + Compatibility with the latest version of boost.
- Dropped boost compatibility patch.
* Sat Sep  4 2010 lazy.kent.suse@gmail.com
- Fixed build against boost-1.44.
* Sun Jun 27 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.1
  + A few user interaction bugs were fixed.
* Mon Jun 14 2010 lazy.kent.suse@gmail.com
- Update to 0.9.9.
  + New feature: Fill Zones.
  + New feature: ordering pages by content box dimensions.
  + New naming scheme for output files.
  + Bugfixes, including two possible crashes.
- Renamed COPYING to COPYING.icons.
* Fri Apr 30 2010 lazy.kent.suse@gmail.com
- Update to 0.9.8.1.
  + Fixed despeckling aggressiveness depending on semi-random factors.
  + Fixed cancelling of new page insertion not always working.
  + For consistency, pure black and white colors are reserved in
    Color / Grayscale mode as well.
  + Minor fixes and improvements at Deskew and Page Layout stages.
- Dropped obsolete despeckling patch.
* Sun Apr 11 2010 lazy.kent.suse@gmail.com
- Fix a problem with despeckling.
* Sat Apr  3 2010 lazy.kent.suse@gmail.com
- Update to 0.9.8.
  + Despeckling: improved algorithm, adjustable, with visualization.
  + Increased binarization adjustment range.
  + Fixed a few crashes.
  + Japanese translation.
  + Disabled OpenGL based UI acceleration due to its instability.
- Dropped obsolete gcc45 patch.
- URL changed to English.
* Sun Feb 21 2010 lazy.kent.suse@gmail.com
- Fixed build with GCC 4.5.
* Tue Jan  5 2010 lazy.kent.suse@gmail.com
- Apply widget patch for openSUSE < 11.2 only.
* Sun Jan  3 2010 lazy.kent.suse@gmail.com
- Initial package created.
- Fixed build with Qt 4.4.x.
